==> nocc-1.8.1.tbz: www/nocc/lang/eu.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: eu.php 1931 2009-07-05 11:07:47Z gerundt $
 */

/** Basque (Euskara)
 *
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author An13sa
 */

$lang_locale = 'en_US.UTF-8';
$alt_delete = 'Ezabatu aukeratutako mezuak';
$alt_delete_one = 'Mezua ezabatu';
$alt_new_msg = 'Mezu berriak';
$alt_reply = 'Egileari erantzun';
$alt_reply_all = 'Denak erantzun';
$alt_next = 'Hurrengoa';
$alt_prev = 'Aurrekoa';
$title_next_page = 'Hurrengo orria';
$title_prev_page = 'Aurreko orria';
$title_next_msg = 'Hurrengo mezua';
$title_prev_msg = 'Aurreko mezua';
$html_login = 'Saioa hasi';
$html_passwd = 'Pasahitza';
$html_submit = 'Baieztatu';
$html_help = 'Laguntza';
$html_server = 'Zerbitzaria';
$html_retry = 'Berriz saiatu';
$html_msgperpage_label = 'Mezuak orriko';
$html_preferences = 'Zehaztapenak';
$html_full_name_label = 'Izen osoa';
$html_email_address_label = 'E-posta Helbidea';
$html_hide_addresses = 'Helbideak ezkutatu';
$html_use_signature = 'Sinadura erabili';
$html_signature = 'Sinadura';
$html_prefs_updated = 'Zehaztapenak eguneratuak';
$html_folders = 'Karpetak';
$html_folders_updated = 'Karpetak eguneratuak';
$html_folder_rename = 'Izena aldatu';
$html_folder_delete = 'Ezabatu';
$html_filter_remove = 'Ezabatu';
$html_select_one = '--Bakarra Aukeratu--';
$html_and = 'Eta';
$html_move = 'Mugitu';
$html_copy = 'Kopiatu';
$html_other_folders = 'Karpeta Zerrenda';
$html_page = 'Orria';
$html_new_msg = 'Idatzi';
$html_delete = 'Ezabatu';
$html_new = 'Berria';
$html_mark = 'Ezabatu';
$html_att_label = 'Eranskina';
$html_atts_label = 'Eranskinak';
$html_attach = 'Erantsi';
$html_subject = 'Gaia';
$html_date = 'Data';
$html_sent = 'Bidali';
$html_size = 'Tamaina';
$html_totalsize = 'Tamaina Guztira';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'byte';
$html_filename = 'Fitxategi izena';
$html_send = 'Bidali';
$html_cancel = 'Ezeztatu';
$html_no_mail = 'Ez dago mezurik.';
$html_logout = 'Saioa itxi';
$html_msg = 'Mezua';
$html_msgs = 'Mezuak';
$html_priority_label = 'Lehentasuna';
$html_lowest = 'Baxuena';
$html_low = 'Baxua';
$html_normal = 'Arrunta';
$html_high = 'Altua';
$html_highest = 'Altuena';
$html_select = 'Aukeratu';
$html_select_all = 'Aukerak Alderantzikatu';
$html_loading_image = 'Irudia kargatzen';
$html_add = 'Gehitu';
$html_contacts = '%1$-(r)en Kontaktuak';
$html_modify = 'Aldatu';
$html_back = 'Atzera';
$html_contact_add = 'Kontaktu berria gehitu';
$html_contact_mod = 'Kontaktua aldatu';
$html_contact_first = 'Izena';
$html_contact_last = 'Abizena';
$html_contact_nick = 'Ezizena';
$html_contact_mail = 'Posta';
$html_contact_err2 = 'Ezin duzu kontaktu berria gehitu';
$html_del_msg = 'Aukeratutako mezuak ezabatu nahi dituzu ?';
$html_down_mail = 'Jaitsi';
$original_msg = '-- Jatorrizko Mezua --';
$html_images_display = 'Irudiak erakutsi';
$lang_could_not_connect = 'Ezin izan da zerbitzarira konektatu';
$html_invalid_email_address = 'E-posta helbide okerra';
$html_search = 'Bilatu';

==> nocc-1.8.3.tbz: www/nocc/lang/eu.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: eu.php 2164 2010-04-05 12:50:59Z gerundt $
 */

/** Basque (Euskara)
 *
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author An13sa
 */

$lang_locale = 'en_US.UTF-8';
$default_date_format = '%Y-%m-%d';
$no_locale_date_format = '%Y-%m-%d';
$default_time_format = '%I:%M %p';
$err_user_empty = 'Saio-hasiera hutsik dago';
$err_passwd_empty = 'Pasahitzaren hutsunea hutsik dago';
$alt_delete = 'Ezabatu aukeratutako mezuak';
$alt_delete_one = 'Mezua ezabatu';
$alt_new_msg = 'Mezu berriak';
$alt_reply = 'Egileari erantzun';
$alt_reply_all = 'Denak erantzun';
$alt_forward = 'Aurrera';
$alt_next = 'Hurrengoa';
$alt_prev = 'Aurrekoa';
$title_next_page = 'Hurrengo orria';
$title_prev_page = 'Aurreko orria';
$title_next_msg = 'Hurrengo mezua';
$title_prev_msg = 'Aurreko mezua';
$html_welcome = 'Ongi etorri %1$s-ra';
$html_login = 'Saioa hasi';
$html_user_label = 'Lankidea:';
$html_passwd_label = 'Pasahitza:';
$html_submit = 'Baieztatu';
$html_help = 'Laguntza';
$html_server_label = 'Zerbitzaria:';
$html_retry = 'Berriz saiatu';
$html_lang_label = 'Hizkuntza:';
$html_msgperpage_label = 'Mezuak orriko:';
$html_preferences = 'Zehaztapenak';
$html_full_name_label = 'Izen osoa:';
$html_email_address_label = 'E-posta helbidea:';
$html_hide_addresses = 'Helbideak ezkutatu';
$html_use_signature = 'Sinadura erabili';
$html_signature = 'Sinadura';
$html_signature_label = 'Sinadura:';
$html_prefs_updated = 'Zehaztapenak eguneratuak';
$html_folders = 'Karpetak';
$html_folders_updated = 'Karpetak eguneratuak';
$html_folder_rename = 'Izena aldatu';
$html_folder_delete = 'Ezabatu';
$html_filter_remove = 'Ezabatu';
$html_select_one = '--Bakarra Aukeratu--';
$html_and = 'Eta';
$html_move = 'Mugitu';
$html_copy = 'Kopiatu';
$html_other_folders = 'Karpeta Zerrenda';
$html_page = 'Orria';
$html_new_msg = 'Idatzi';
$html_delete = 'Ezabatu';
$html_new = 'Berria';
$html_mark = 'Ezabatu';
$html_att_label = 'Eranskina:';
$html_unknown = '[ezezaguna]';
$html_attach = 'Erantsi';
$html_sort = 'Ordenatu';
$html_from = 'Igorlea';
$html_subject = 'Gaia';
$html_subject_label = 'Gaia:';
$html_date = 'Data';
$html_date_label = 'Data:';
$html_sent_label = 'Bidalita:';
$html_size = 'Tamaina';
$html_totalsize = 'Tamaina Guztira';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'byte';
$html_filename = 'Fitxategi izena';
$html_to_label = 'Nori:';
$html_send = 'Bidali';
$html_cancel = 'Ezeztatu';
$html_no_mail = 'Ez dago mezurik.';
$html_logout = 'Saioa itxi';
$html_msg = 'Mezua';
$html_msgs = 'Mezuak';
$html_priority = 'Lehentasuna';
$html_priority_label = 'Lehentasuna:';
$html_lowest = 'Baxuena';
$html_low = 'Baxua';
$html_normal = 'Arrunta';
$html_high = 'Altua';
$html_highest = 'Altuena';
$html_select = 'Aukeratu';
$html_select_all = 'Aukerak Alderantzikatu';
$html_loading_image = 'Irudia kargatzen';
$html_add = 'Gehitu';
$html_contacts = '%1$-(r)en Kontaktuak';
$html_modify = 'Aldatu';
$html_back = 'Atzera';
$html_contact_add = 'Kontaktu berria gehitu';
$html_contact_mod = 'Kontaktua aldatu';
$html_contact_first = 'Izena';
$html_contact_last = 'Abizena';
$html_contact_nick = 'Ezizena';
$html_contact_mail = 'Posta';
$html_contact_err2 = 'Ezin duzu kontaktu berria gehitu';
$html_del_msg = 'Aukeratutako mezuak ezabatu nahi dituzu ?';
$html_down_mail = 'Jaitsi';
$original_msg = '-- Jatorrizko Mezua --';
$html_images_display = 'Irudiak erakutsi';
$lang_could_not_connect = 'Ezin izan da zerbitzarira konektatu';
$html_invalid_email_address = 'E-posta helbide okerra';
$html_search = 'Bilatu';
